@@ -59,6 +59,20 @@ for i in $BORDERLINKS; do
   ln -sf ../$i /ram1/$i
 done
 
+# if udev is used, make sure udev is mounted on /dev
+# Reason is that as /etc/init.d/udev was called /dev pointed to /dev.ro
+# Without "mount --move" for example /dev/pts/* will not be created, 
+# but /dev.ro/pts/* will be managed by udev.
+[ "$(mount | grep "^udev\>.*dev.ro\>")" ] && mount --move /dev.ro /dev
+
+# Next lines are no longer needed, instead the line before does 
+# the job in the right way.
+# Recreate udev (needed for kernel >2.6.8)
+#if [ -x /etc/init.d/udev ]; then 
+  #/etc/init.d/udev stop
+  #/etc/init.d/udev start
+#fi
+
 mke2fs -q $INODES /dev/ram2 # Size is defined by ramdisk_size at boottime
 mount /dev/ram2 /ram2 -o defaults,rw
 if [ -f /ram2.cpio.gz ]; then
@@ -80,8 +94,3 @@ for i in $CHNG; do
   ln -s $i $j
 done
 
-# Recreate udev (needed for kernel >2.6.8)
-if [ -x /etc/init.d/udev ]; then 
-  /etc/init.d/udev stop
-  /etc/init.d/udev start
-fi
